@@ -81,7 +81,7 @@ apply_niche.pre_paleoTS = function(x, niche_def, gc){
   thin_vals = change_in_niche(x$t)
   for (i in seq_along(thin_vals)){
     r = prob_remove(x$vals[[i]], prob = thin_vals[i])
-    x$vals[[i]] = x$vals[[i]][as.logical(r)]
+    x$vals[[i]] = r
   }
   return(x)
 }
